"""Base MySchoolBucks Class."""
import logging

from .models.student import Student
from .msb_api_client import MySchoolBucksApiClient

_LOGGER = logging.getLogger(__name__)
_LOGGER.setLevel(logging.INFO)


class MySchoolBucks():
    """Define MySchoolBucks Class."""
    def __init__(
        self,
        base_url,
        username,
        secret,
        district,
        path: str = None,
        debug=False,
    ):
        self._api_client = MySchoolBucksApiClient(base_url, username, secret, district, path, debug)

        if debug:
            _LOGGER.setLevel(logging.DEBUG)

    async def authenticate(self, session) -> bool:
        """Authenticate with mySchoolBucks."""
        authresp = await self._api_client.authenticate(session)
        return authresp

    async def students(self) -> list[Student]:
        """Get Students."""
        studentsresp = await self._api_client.get_students()
        students = [Student(response) for response in studentsresp]
        return students